@@ -165,7 +165,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -181,26 +181,26 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_dynamodb
-import aws_cdk.aws_iot
-import aws_cdk.aws_lambda
-import constructs
+import aws_cdk.aws_dynamodb as _aws_cdk_aws_dynamodb_ceddda9d
+import aws_cdk.aws_iot as _aws_cdk_aws_iot_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class IotToLambdaToDynamoDB(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-lambda-dynamodb.IotToLambdaToDynamoDB",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+        dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -217,7 +217,7 @@ class IotToLambdaToDynamoDB(
         :summary: Constructs a new instance of the IotToLambdaToDynamoDB class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IotToLambdaToDynamoDB.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__59c8611af9fdcb1ce543f81724c06e8bc8cc0e01d77f48a7f6976e0e961c429c)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToLambdaToDynamoDBProps(
@@ -232,18 +232,18 @@ class IotToLambdaToDynamoDB(
 
     @builtins.property
     @jsii.member(jsii_name="dynamoTable")
-    def dynamo_table(self) -> aws_cdk.aws_dynamodb.Table:
-        return typing.cast(aws_cdk.aws_dynamodb.Table, jsii.get(self, "dynamoTable"))
+    def dynamo_table(self) -> _aws_cdk_aws_dynamodb_ceddda9d.Table:
+        return typing.cast(_aws_cdk_aws_dynamodb_ceddda9d.Table, jsii.get(self, "dynamoTable"))
 
     @builtins.property
     @jsii.member(jsii_name="iotTopicRule")
-    def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
-        return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
+    def iot_topic_rule(self) -> _aws_cdk_aws_iot_ceddda9d.CfnTopicRule:
+        return typing.cast(_aws_cdk_aws_iot_ceddda9d.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
     @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
-    def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
+    def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "lambdaFunction"))
 
 
 @jsii.data_type(
@@ -261,10 +261,10 @@ class IotToLambdaToDynamoDBProps:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+        dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -277,19 +277,19 @@ class IotToLambdaToDynamoDBProps:
         :summary: The properties for the IotToLambdaToDynamoDB class.
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = _aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+            dynamo_table_props = _aws_cdk_aws_dynamodb_ceddda9d.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**lambda_function_props)
         if __debug__:
-            type_hints = typing.get_type_hints(IotToLambdaToDynamoDBProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4abf9105fca6670b5209365799827a59d704a6a776881efc469c3d278696635f)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
             check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
             check_type(argname="argument table_permissions", value=table_permissions, expected_type=type_hints["table_permissions"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
         if dynamo_table_props is not None:
@@ -302,43 +302,47 @@ class IotToLambdaToDynamoDBProps:
             self._values["table_permissions"] = table_permissions
 
     @builtins.property
-    def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
+    def iot_topic_rule_props(self) -> _aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps:
         '''User provided props to override the default props.
 
         :default: - Default props are used
         '''
         result = self._values.get("iot_topic_rule_props")
         assert result is not None, "Required property 'iot_topic_rule_props' is missing"
-        return typing.cast(aws_cdk.aws_iot.CfnTopicRuleProps, result)
+        return typing.cast(_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, result)
 
     @builtins.property
-    def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
+    def dynamo_table_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.TableProps]:
         '''Optional user provided props to override the default props.
 
         :default: - Default props are used
         '''
         result = self._values.get("dynamo_table_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.TableProps], result)
 
     @builtins.property
-    def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    def existing_lambda_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
     def lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used
         '''
         result = self._values.get("lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
     def table_permissions(self) -> typing.Optional[builtins.str]:
@@ -369,3 +373,27 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__59c8611af9fdcb1ce543f81724c06e8bc8cc0e01d77f48a7f6976e0e961c429c(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    table_permissions: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4abf9105fca6670b5209365799827a59d704a6a776881efc469c3d278696635f(
+    *,
+    iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    table_permissions: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
